#
# spec file for package cfitsio
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define tar_ver 3390
%define so_ver 5

Name:           cfitsio
Version:        3.390
Release:        2.5
Summary:        Library for manipulating FITS data files
License:        ISC
Group:          Productivity/Scientific/Other
Url:            http://heasarc.nasa.gov/fitsio/
Source0:        ftp://heasarc.gsfc.nasa.gov/software/fitsio/c/%{name}%{tar_ver}.tar.gz
# PATCH-FIX-OPENSUSE cfitsio-zlib.patch asterios.dramis@gmail.com -- Use system zlib, link programs to shared libcfitsio (based on patches from Fedora and Debian)
Patch0:         cfitsio-zlib.patch
BuildRequires:  gcc-fortran
BuildRequires:  pkg-config
BuildRequires:  zlib-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
CFITSIO is a library of C and Fortran subroutines for reading and writing data
files in FITS (Flexible Image Transport System) data format. CFITSIO provides
simple high-level routines for reading and writing FITS files that insulate the
programmer from the internal complexities of the FITS format. CFITSIO also
provides many advanced features for manipulating and filtering the information
in FITS files.

This package contains some FITS image compression and decompression utilities.

%package devel
Summary:        Headers required when building programs against cfitsio library
Group:          Development/Libraries/Other
Requires:       libcfitsio%{so_ver} = %{version}
Requires:       pkg-config
Suggests:       cfitsio-devel-doc = %{version}
# libcfitsio-devel was last used in openSUSE 13.1 (version 3.350)
Provides:       libcfitsio-devel = %{version}
Obsoletes:      libcfitsio-devel <= 3.350

%description devel
This package contains headers required when building programs against cfitsio
library.

%package devel-doc
Summary:        Documentation for the cfitsio library
Group:          Documentation/Other
# libcfitsio-doc was last used in openSUSE 12.1 (version 3.280)
Obsoletes:      libcfitsio-doc <= 3.280
# libcfitsio-devel was last used in openSUSE 13.1 (version 3.350)
Provides:       libcfitsio-devel-doc = %{version}
Obsoletes:      libcfitsio-devel-doc <= 3.350

%description devel-doc
This package contains documentation for the cfitsio library.

%package -n libcfitsio%{so_ver}
Summary:        Library for manipulating FITS data files
Group:          System/Libraries

%description -n libcfitsio%{so_ver}
CFITSIO is a library of C and Fortran subroutines for reading and writing data
files in FITS (Flexible Image Transport System) data format. CFITSIO provides
simple high-level routines for reading and writing FITS files that insulate the
programmer from the internal complexities of the FITS format. CFITSIO also
provides many advanced features for manipulating and filtering the information
in FITS files.

%prep
%setup -q -n %{name}
%patch0 -p1

# Remove bundled zlib
pushd zlib
rm -f adler32.c crc32.c crc32.h deflate.c deflate.h infback.c inffast.c \
 inffast.h inffixed.h inflate.c inflate.h inftrees.c inftrees.h trees.c trees.h \
 uncompr.c zconf.h zlib.h zutil.c zutil.h
popd

%build
# lines bellow contain fixes for pkgconfig file bnc#546004, some of them are already fixed by upstream
# so please drop them if they are not needed (in next round of updates)
# Add include dir, multithreading support, zlib dependency
sed -i 's|Cflags: -I${includedir}|Cflags: -D_REENTRANT -I${includedir} -I${includedir}/%{name}|' cfitsio.pc.in
sed -i 's|Libs: -L${libdir} -lcfitsio @LIBS@|Libs: -L${libdir} -lcfitsio|' cfitsio.pc.in
sed -i 's|Libs.private: -lm|Libs.private: @LIBS@ -lz -lm|' cfitsio.pc.in

%configure --enable-reentrant
make shared %{?_smp_mflags}
make fpack %{?_smp_mflags}
make funpack %{?_smp_mflags}

%check
# testsuite
make testprog %{?_smp_mflags}
LD_LIBRARY_PATH=. ./testprog > testprog.lis
diff testprog.lis testprog.out
cmp testprog.fit testprog.std ; echo $?

%install
make DESTDIR=%{buildroot} CFITSIO_INCLUDE=%{buildroot}%{_includedir}/%{name} install

# Remove static libraries
rm -f %{buildroot}%{_libdir}/libcfitsio.a

%post -n libcfitsio%{so_ver} -p /sbin/ldconfig

%postun -n libcfitsio%{so_ver} -p /sbin/ldconfig

%files
%defattr(-,root,root,-)
%doc License.txt README docs/{changes.txt,fpackguide.pdf}
%{_bindir}/fpack
%{_bindir}/funpack

%files devel
%defattr(-,root,root,-)
%{_includedir}/%{name}/
%{_libdir}/libcfitsio.so
%{_libdir}/pkgconfig/cfitsio.pc

%files devel-doc
%defattr(-,root,root,-)
%doc docs/{cfitsio.doc,cfitsio.ps,cfortran.doc,fitsio.doc,fitsio.ps,quick.ps}

%files -n libcfitsio%{so_ver}
%defattr(-,root,root,-)
%{_libdir}/libcfitsio.so.%{so_ver}*

%changelog
* Sun Jun 26 2016 asterios.dramis@gmail.com
- Update to version 3.390:
  * Lots of changes - see changes.txt for details.
- Rebased cfitsio-zlib.patch to apply cleanly.
* Thu Dec 25 2014 p.drouand@gmail.com
- Update to version 3.370
  + Added configure options to support reading bzip2 compressed FITS files.
    This depends on having the bzlib library installed on the local machine.
  + Replaced the random Gaussian and Poissonian distribution functions with
    new code written by Craig Markwardt derived from public domain C++ functions
  + Patched fitsio2.h to support CFITSIO on AArch64 (64-bit ARM)
    architecture (both big and little endian).
  + Fixed bug in fpackutil.c that caused fpack to exit prematurely if
    the FZALGOR directive keyword was present in the HDU header.
- Remove obsolete patches; fixed on upstream release
  + aarch64-support.patch
  + ppc64le-support.patch
* Sun Feb 16 2014 asterios.dramis@gmail.com
- Update to version 3.360:
  * added 9 Dec: small change to the fileseek function in drvrfile.c to
    support large files > 2 GB when building CFITSIO with MinGW on Windows
  * reorganized the CFITSIO code directory structure; added a 'docs'
    subdirectory for all the documentation, and a 'zlib' directory
    for the zlib/gzip file compression code.
  * made major changes to the compression code for FITS binary table
    to support all types of columns, including variable-length arrays.
    This code is mainly used via the fpack and funpack programs.
  * increased the number of FITS files that can be opened as one
    time to 1000, as defined by NMAXFILES in fitsio2.h.
  * made small configuration changes to configure.in, configure,
    fitsio.h, and drvrfile.c to support large files (64-bit file
    offsets} when using the mingw-w64 compiler (provided by
    Benjamin Gilbert).
  * made small change to fits_delete_file to more completely ignore
    any non-zero input status value.
  * fixed a logic error in a 'if' test when parsing a keyword name
    in the ngp_keyword_is_write function in grparser.c (provided
    by David Binderman).
  * when specifying the image compression parameters as part of the
    compressed image file name (using the "[compress]" qualifier
    after the name of the file), the quantization level value, if
    specified, was not being recognized by the CFITSIO compression
    routines. The image would always be compressed with the default
    quantization level of 4.0, regardless of what was specified.  This
    affected the imcopy program, and potentially other user-generated
    application programs that used this method to specify the
    compression parameters.  This bug did not affect fpack or
    funpack.   This was fixed in the imcomp_get_compressed_image_par
    routine in the imcompress.c file. (reported by Sean Peters)
  * defined a new CFITS_API macro in fitsio.h which is used to export the
    public symbols when building CFITSIO on Windows systems with CMake. This
    works in conjunction with the new Windows CMake build procedure that
    is described in the README.win32 file. This complete revamping of the
    way CFITSIO is built under Windows now supports building 64-bit
    versions of the library.  Thanks to Daniel Kaneider (Luminance HDR
    Team) for providing these new  CMake build procedures.
  * modified the way that the low-level file_create routine works when
    running in the Hera environment to ensure that the FITS file that is
    created is within the allow user data disk area.
  * modified fits_get_compression_type so that it does not return an error
    if the HDU is a normal FITS IMAGE extension, and is not a tile-compressed
    image.
  * modified the low-level ffgcl* and ffpcl* routines to ensure that they
    never try ro read or write more than 2**31 bytes from disk at one time,
    as might happen with very large images, to avoid integer overflow errors.
    Fix kindly provided by Fred Gutsche at NanoFocus AG (www.nanofocus.de).
  * modified Makefile.in so that doing 'make distclean' does not delete
    new config.sub and config.guess files that were recently added.
  * adopted a patch from Debian in zcompress.c to "define" the values of
    GZBUFSIZE and BUFFINCR, instead of exporting the symbols as 'int's.
- Renamed libcfitsio-devel to cfitsio-devel and libcfitsio-devel-doc to
  cfitsio-devel-doc. Added appropriate Provides/Obsoletes entries.
- Removed the following patches (fixed upstream):
  * implicit-pointer-decl.patch
  * no-return-in-nonvoid-function.patch
- Rebased cfitsio-zlib.patch to apply cleanly.
* Sun Dec 15 2013 uweigand@de.ibm.com
- ppc64le-support.patch: Add support for ppc64le.
* Sun Jul  7 2013 asterios.dramis@gmail.com
- Update to version 3.350:
  * fixed problem with the default tile size when compressing images with
    fpack using the Hcompress algorithm.
  * fixed returned value ("status" instead of "*status")
  * in imcompress.c, declared some arrays that are used to store the dimensions
    of the image from 'int' to 'long', to support very large images (at least
    on systems where sizeof(long) = 8),
  * modified the routines that convert a string value to a float or double
    to prevent them from returning a NaN or Inf value if the
    string is "NaN" or "Inf" (as can happen with gcc implementation of the
    strtod function).
  * removed/replaced the use of the assert() functions when locking or
    unlocking threads because they did not work correctly if NDEBUG is
    defined.
  * made modifications to the way the command-line file filters are parsed to
    1) remove the 1024-character limit when specifying a column filter,
    2) fixed a potential character buffer-overflow risk in fits_get_token, and
    3) improved the parsing logic to remove any possible of confusing
    2 slash characters ("//") in the string as the beginning of a
    comment string.
  * modified configure and Makefile.in so that when building CFITSIO
    as a shared library on linux or Mac platforms, it will use the SONAME
    convention to indicate whether each new release of the CFITSIO
    library is binary-compatible with the previous version.  Application
    programs that link with the shared library will not need to be
    recompiled as long as the versions are compatible.  In practice,
    this means that the shared library binary file that is created (on
    Linux systems) will have a name like 'libcfitsio.so.I.J.K', where I is the
    SONAME version number, J is the major CFITSIO version number (e.g. 3),
    and K is the minor CFITSIO version number (e.g., 34).  Two link
    files will also be created such that
    libcfitsio.so -> libcfitsio.so.I, and
    libcfitsio.so.I -> libcfitsio.I.J.K
    Application programs will still run correctly with the new version of
    CFITSIO as long as the 'I' version number remains the same, but the
    applications will fail to run if the 'I' number changes, thus alerting
    the user that the application must be rebuilt.
  * fixed bug in fits_insert_col when computing the new table row width
    when inserting a '1Q' variable length array column.
  * modified the image compression routines so that the output compressed
    image (stored in a FITS binary table) uses the '1Q' variable length
    array format (instead of '1P') when the input file is larger than 4 GB.
  * added support for "compression directive" keywords which indicate how
    that HDU should be compressed (e.g., which compression algorithm to use,
    what tiling pattern to use, etc.).  The values of these keywords will
    override the compression parameters that were specified on the command
    line when running the fpack FITS file compression program.
  * globally changed the variable and/or subroutine name "dither_offset"
    to "dither_seed" and "quantize_dither" to "quantize_method" so
    that the names more accurately reflects their purpose.
  * added support for a new SUBTRACTIVE_DITHER_2 method when compressing
    floating point images.  The only difference with the previous method
    is that pixels with a value exactly equal to 0.0 will not be dithered,
    and instead will be exactly preserved when the image is compressed.
  * added support for an alias of "RICE_ONE" for "RICE_1" as the value
    of the ZCMPTYPE keyword, which gives the name of the image compression
    algorithm.  This alias is used if the new SUBTRACTIVE_DITHER_2 option
    is used, to prevent old versions of funpack from creating a corrupted
    uncompressed image file.  Only newer versions of funpack will recognize
    this alias and be able to uncompress the image.
  * made performance improvement to fits_read_compressed_img so that
    when reading a section of an compressed image that includes only
    every nth pixel in some dimension, it will only uncompressed a tile
    if there are actually any pixels of interest in that tile.
  * fixed several issues with the beta FITS binary table compression code
    that is used by fpack:  added support for zero-length vector columns,
    made improvements to the output report when using the -T option in fpack,
    changed the default table compression method to 'Rice' instead of
    'Best', and now writes the 'ZTILELEN' keyword to document the number
    of table rows in each tile.
  * fixed error in ffbinit in calculating the total length of the binary
    table extension if the THEAP keyword was used to override the
    default starting location of the heap.
- Removed cfitsio.patch (fixed upstream).
- Rebased cfitsio-zlib.patch to apply cleanly.
- Added a patch (no-return-in-nonvoid-function.patch) to fix "Program returns
  random data in a function" rpm post build check error.
* Sun Jun 16 2013 schwab@suse.de
- aarch64-support.patch: Add support for aarch64
* Wed Apr  3 2013 asterios.dramis@gmail.com
- Update to version 3.340:
  * modified configure and configure.in to support cross-compiled cfitsio
    as a static library for Windows on a Linux platform using MXE
    (http://mxe.cc) - a build environment for mingw32. (contributed by
    Niels Kristian Bech Jensen)
  * added conditional compilation statementsfor the mingw32 environment in
    drvrfile.c because mingw32 does not include the ftello and fseeko
    functions. (contributed by Niels Kristian Bech Jensen)
  * fixed a potential bug in ffcpcl (routine to copy a column from one table
    to another table) when dealing with the rare case of a '0X' column (zero
    length bit column).
  * fixed an issue in the routines that update or modify string-valued
    keyword values, as a result of the change to ffc2s in the previous
    release.  These routines would exit with a 204 error status if the
    current value of the keyword to be updated or modified is null.
  * fixed typo in the previous modification that was intended to ignore
    numerical overflows in Hcompress when decompressing an image.
  * moved the 'startcol' static variable out of the ffgcnn routine and
    instead added it as a member of the 'FITSfile' structure that is defined
    in fitsio.h.  This removes a possible race condition in ffgcnn in
    multi-threaded environments.
  From version 3.330:
  * modified the imcomp_decompress_tile routine to ignore any numerical
    overflows that might occur when using Hcompress to decompress the
    image.  If Hcompress is used in its 'lossy' mode, the uncompressed
    image pixel values may slightly exceed the range of an integer*2
    variable. This is generally of no consequence, so we can safely ignore
    any overflows in this case and just clip the values to the legal range.
  * the default tiling pattern when writing a tile-compressed image
    has been changed.  The old behaviour was to compress the whole image
    as one single large tile.  This is often not optimal when dealing
    with large images, so the new default behavior is to treat each
    row of the image as one tile.  This is the same default behavior
    as in the standalone fpack program.  The default tile size can
    be overridden by calling fits_set_tile_dim.
  * fixed bug bug that resulted in a corrupted output FITS image when
    attempting to write a float or double array of values to a
    tile-compressed integer data type image.  CFITSIO does not support
    implicit data type conversion in this case and now correctly
    returns an appropriate error status.
  * modified ricecomp.c to define the nonzero_count lookup table as an
    external variable, rather then dynamically allocating it within the
    3 routines that use it.  This simplifies the code and eliminates the
    need for special thread locking and unlocking statements. (Thanks to
    Lars Kr. Lundin for this suggestion).
  * modifed how the uncompressed size of a gzipped file is computed in the
    mem_compress_open routine in drvrmem.c.  Since gzip only uses 4 bytes
    in the compressed file header to store the original file size, one may
    need to apply a modulo 2^32 byte correction in some cases.  The logic
    here was modified to allow for corner cases (e.g., very small files, and
    when running on 32-bit platforms that do not support files larger than
    2^31 bytes in size).
  * added new public routine to construct a 80 keyword record from the 3 input
    component strings, i.e, the keyword name string, the value string, and
    the comment string: fits_make_key/ffmkky.  (This was already an undocumented
    internal routine in previous versions of CFITSIO).
  * modified ffc2s so that if the input keyword value string is a null string,
    then it will return a VALUE_UNDEFINED (204) status value.  This makes it
    consistent with the behavior when attempting to read a null keyword
    (which has no value) as a logical or as a number (which also returns
    the 204 error).  This should only affect cases where the header keyword
    does not have an equal sign followed by a space character in columns 9
    and 10 of the header record.
  * Changed the "char *" parameter declarations to "const char *" in many
    of the routines (mainly the routines that modify or update keywords) to
    avoid compiler warnings or errors from C++ programs that tend to be more
    rigorous about using "const char *" when appropriate.
  * added support for caching uncompressed image tiles, so that the tile does
    not need to be uncompressed again if the application program wants
    to read more data from the same tile. This required changes to the
    main FITS file structure that is defined in fitsio.h, as well as
    changes to imcompress.c.
  * enhanced the previous modification to drvrfile.c to handle additional user
    cases when running in the HEASARC's Hera environment.
  From version 3.320:
  * fixed flaw in the way logical columns (TFORM = 'L') in binary tables
    were read which caused an illegal value of 1 in the column to be
    interpreted as a 'T' (TRUE) value.
  * extended the column filtering syntax in the CFITSIO file name parser to
    enable users and scripts to append new COMMENT or HISTORY keyword into the
    header of the filtered file (provided by Craig Markwardt).  For example,
    fcopy "infile.fits[col #HISTORY='Processed on 2012-10-05']" outfile.fits
    will append this header keyword: "HISTORY Processed on 2012-10-05"
  * small change to the code that opens and reads an ASCII region file to
    return an error if the file is empty.
  * fixed obscure sign propagation error when attempting to read the
    uncompressed size of a gzipped FITS file.  This resulted in a memory
    allocation error if the gzipped file had an uncompressed file
    size between 2^31 and 2^32 bytes.  Fix supplied by Gudlaugur Johannesson
    (Stanford).
- Rebased cfitsio.patch to apply cleanly.
* Tue Jul 31 2012 asterios.dramis@gmail.com
- Update to version 3.310:
  * Enhanced the CFITSIO column filtering syntax to allow the comma, in
    addition to the semi-colon, to be used to separate clauses, for example:
    [col X,Y;Z = max(X,Y)].  This was done because users are not allowed to
    enter the semi-colon character in the on-line Hera data processing
    system due to computer security concerns.
  * Enhanced the CFITSIO extended filename syntax to allow specifying image
    compression parameters (e.g. '[compress Rice]') when opening an existing
    FITS file with write access.  The specified compression parameters will
    be used by default if more images are appended to the existing file.
  * Modified drvrfile.c to do additional file secrity checks when CFITSIO
    is running within the HEASARC's Hera software system.  In this case
    CFITSIO will not allow FITS files to be created outside of the user's
    individual Hera data directory area.
  * Fixed an issue in fpack and funpack on Windows machines, caused by
    the fact that the 'rename' function behaves differently on Windows
    in that it does not clobber an existing file, as it does on Unix
    platforms.
  * Fixed bug in the way byte-swapping was being performed when writing
    integer*8 null values to an image or binary table column.
  * Added the missing macro definition for fffree to fitsio.h.
  * Modified the low level table read and write functions in getcol*.c and
    putcol*.c to remove the 32-bit limitation on the number of elements.
    These routines now support reading and writing more than 2**31 elements
    at one time. Thanks to Keh-Cheng Chu (Stanford U.) for the patch.
  * Modified Makefile.in so that the shared libcfitsio.so is linked against
    pthreads and libm.
- Removed the fix to link the library to libpthread and libm from cfitsio.patch
  (fixed upstream).
- Rebased cfitsio-zlib.patch to apply cleanly. Removed the linking of the
  programs (fpack and funpack) to libz from the patch (not needed).
- Remove some more bundled zlib files from the package.
* Wed May  9 2012 asterios.dramis@gmail.com
- Renamed package from libcfitsio0 to cfitsio.
- Renamed subpackage libcfitsio-doc to libcfitsio-devel-doc (added obsoletes
  entry for libcfitsio-doc of previous openSUSE versions).
- Suggest the libcfitsio-devel-doc package in libcfitsio-devel.
- Removed the requirement for libcfitsio0 from libcfitsio-(devel)-doc (not
  needed).
* Tue May  8 2012 asterios.dramis@gmail.com
- Update to version 3.300:
  Enhancements
  * Added new routine called fits_is_reentrant which returns 1 or 0 depending
    on whether or not CFITSIO was compiled with the -D_REENTRANT directive.
    This can be used to determine if it is safe to use CFITSIO in
    multi-threaded programs.
  * Implimented much faster byte-swapping algorithms in swapproc.c based on
    code provided by Julian Taylor at ESO, Garching.  These routines
    significantly improve the FITS image read and write speed (by more than a
    factor of 2 in some cases) on little-endian machines (e.g., Linux and
    Microsoft Windows running on x86 PCs) where byte-swapping is required.
    This has no effect on big-endian machines (e.g., Macs).  Even faster
    performance can be achieved in some cases by invoking the new
    "--enable-sse2" or "--enable-ssse3" configure options when building CFITSIO
    on machines that have CPUs and compilers that support the SSE2 and SSSE3
    machine instructions.
  * added additional support for implicit data type conversion in cases where
    the floating point image has been losslessly compressed with gzip.  The
    pixels in these compressed images can now be read back as arrays of short,
    int, and long integers as well as single and double precision
    floating-point.
  * modified fitsio2.h and f77_wrap.h to recognize IBM System z mainframes by
    testing if __s390x__ or __s390__ is defined.
  * small change to ffgcrd in getkey.c so that it supports reading a blank
    keyword (e.g., a keyword whose name simply contains 8 space chracters).
  Bug Fixes
  * fixed a bug in imcomp_decompress_tile that caused the tile-compressed image
    to be uncompressed incorrectly (even though the tile-compressed image
    itself was written correctly) under the following specific conditions:
  - the original FITS image has a "float" datatype (R*4)
  - one or more of the image tiles cannot be compressed using the standard
    quantization method  and instead are losslessly compressed with gzip
  - the pixels in these tiles are not all equal to zero (this bug does
    affect tiles where all the pixels are equal to zero)
  - the program that is reading the compressed image uses CFITSIO's
    "implicit datatype conversion" feature to read the "float" image
    back into an array of "double" pixel values.
    If all these conditions are met, then the returned pixel values in the
    affected image tiles will be garbage, with values often ranging
    up to 10**34.  Note that this bug does not affect the fpack/funpack
    programs, because funpack does not use CFITSIO's implicit datatype
    conversion feature when uncompressing the image.
- Replaced cfitsio-makefile.patch with cfitsio.patch (taken from Fedora). It's
  the same patch with the addition of linking libcfitsio with libpthread and
  libm (fixes possible errors with packages requiring libcfitsio0 and compiled
  with the "--as-needed" flag).
- Added a patch (cfitsio-zlib.patch) to use system zlib (based on patches from
  Fedora and Debian). Added zlib-devel in build depencdencies.
- Added a patch (implicit-pointer-decl.patch) to fix "implicit-pointer-decl"
  rpm post build check warning.
- Moved "-lpthread" and added "-lz" in Libs.private: of cfitsio pkg-config
  file.
- Removed "-fno-strict-aliasing" from CFLAGS.
- Don't install static libraries.
* Mon Dec  5 2011 idoenmez@suse.de
- Set license to ISC, bnc#734865
* Sun Dec  4 2011 idoenmez@suse.de
- Fix SLE_11 build
* Sun Dec  4 2011 asterios.dramis@gmail.com
- Update to version 3.290:
  Enhancements
  * modified Makefile.in to allow configure to override the lib and include
    destination directories.
  * added (or restored actually) support for tile compression of 1-byte integer
    images in imcomp_compress_tile.  Support for that data type was overlooked
    during recent updates to this routine.
  * modified the fits_get_token command-line parsing routine to perform more
    rigorous checks to determine if the token can be interpreted as a number
    or not.
  * made small modification to fpack.c to not allow the -i2f option (convert
    image from integer to floating point) with the "-g -q 0" option (do lossless
    gzip compression).  It is more efficient to simply use the -g option alone.
  * made modifications to fitsio.h and drvrfile.c to support reading and
    writing large FITS files (> 2.1 GB) when building CFITSIO using
    Microsoft Visual C++ on Windows platforms.
  * added new WCS routine (ffgicsa) which returns the WCS keyword values
    for a particular WCS version ('A' - 'Z').
  Bug Fixes
  * fixed a problem with multi-threaded apps that open/close FITS files
    simultaneously by putting mutex locks around the call to
    fits_already_open and in fits_clear_Fptr.
  * fixed a bug when using the 'regfilter' function to select a subset of the
    rows in a FITS table that have coordinates that lie within a specified
    spatial region on the sky.  This bug only affects the rarely used panda
    (and epanda and bpanda) region shapes in which the region is defined by
    the intersection of an annulus  and a pie-shaped wedge.  The previous code
    (starting with version 3.181 of CFITSIO where support for the panda region
    was first introduced) only worked correctly if the 2 angles that define
    the wedge have values between -180 and +180.  If not, then fewer rows than
    expected may have been selected from the table.
  * fixed the extended filename parser so that when creating a histogram by
    binning 2 table columns, if a keyword or column name is given as the
    weighting factor,  then the output histrogram image will have a floating
    point datatype, not the default integer datatype as is the case when no
    weigth is specified (e.g. with a filename like
    "myfile.fits[bin x,y; weight_column]"
  * added fix to the code in imcompress.c to work around a problem with
    dereferencing the value of a pointer, in cases where the address of
    that pointer has not been defined (e.g., the nulval variable).
  * modified the byte shuffling algorithm in fits_shuffle_8bytes to work
    around a strange bug in the proprietary SunStudioExpress C compiler
    under OpenSolaris.
  * removed spurious messages on the CFITSIO error stack when opening a
    FITS file with FTP (in drvrnet.c);
- Removed the Makefile.in changes from cfitsio-makefile.patch (fixed upstream).
- Spec file updates:
  * Changed License entry to SPDX style.
  * Enable multithreading support.
* Tue Oct  4 2011 asterios.dramis@gmail.com
- Added correct fix for cfitsio.pc include dirs (Cflags: was wrongly replaced
  with $Cflags:). Fixes reopened bnc#546004.
* Fri Sep 16 2011 asterios.dramis@gmail.com
- update to version 3.280
  * Lots of changes (see changes.txt file).
- Spec file updates
  * Changes based on spec-cleaner run.
  * Updates in summaries and descriptions.
  * Updates in Group: entries of the packages.
  * Added description for the patch based on openSUSE Patches Guidelines.
  * Added pkg-config in BuildRequires: (fix for "no-pkg-config-provides"
    rpmlint warning).
  * Added cfitsio package (containing some utilities).
  * Fixes for cfitsio.pc.
  * Minor other updates.
* Thu May 20 2010 tittiatcoke@gmail.com
- update to version 3.23.0,
  * reduced the default value for the floating point image
    quantization parameter (q) from 16 to 4.
  * enhanced the template keyword parsing routine to reject a
    header template string that only contains a sequence of dashes.
  * enhanced the ASCII region file reading routine to allow tabs
    as well as spaces between fields in the file.
  * got rid of bogus error message when calling
    fits_update_key_longstr
  * Made the error message more explicit when CFITSIO tries to
    write to a GZIP compressed file.
  * several bugfixes
* Wed May 19 2010 mseben@novell.com
- fix libdir,include dir and version string in pkgconfig (bnc#546004)
* Thu Jan  8 2009 mseben@suse.cz
- update to version 3.18.1, see full changelog :
  http://heasarc.gsfc.nasa.gov/FTP/software/fitsio/c/changes.txt
* Tue Aug 12 2008 lmichnovic@suse.cz
- update to version 3.09
  * added a clarification to the cfortran.doc file that cfortran.h
  may be used and distributed under the terms of the GNU Library
  General Public License.
  * many many bugfixes
- obsoletes strncat_overflow.patch
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Thu Nov 15 2007 lmichnovic@suse.cz
- switched to gcc-fortran in BuildRequires
* Mon Oct 15 2007 lmichnovic@suse.cz
- fixed buffer overflow using strncat
  (cfitsio-strncat_overflow.patch)
* Mon Oct 15 2007 lmichnovic@suse.cz
- update to version 3.06
  * modified the imcopy.c utility program (to tile-compress images)
    so that it writes the default EXTNAME = 'COMPRESSED_IMAGE'
    keyword in the compressed images, to preserve the behavior of
    earlier versions of imcopy.
  * modified the angsep function in the FITS calculator (in eval.y)
    to use haversines, instead of the 'law of cosines', to provide
    more precision at small angles (< 0.1 arcsec).
  * extensive changes to imcompress.c to fully support implicit
    data type conversion when reading and writing arrays of data
    to FITS images, where the data type of the array is not the
    same as the data type of the FITS image.  This includes
    support for null pixels, and data scaling via the BSCALE and
    BZERO keywords.
  * rewrote the fits_read_tbl_coord routine in wcssub.c, that gets
    the standard set of WCS keywords appropriate to a pair of
    columns in a table, to better support the full set of
    officially approved WCS keywords.
  * made significant changes to histo.c, which creates an image by
    binning columns of a table, to better translate the WCS
    keywords in the table header into the WCS keywords that are
    appropriate for an image HDU.
  * modified imcompress.c so that when pixels are written to a
    tile-compressed image, the appropriate BSCALE and BZERO values
    of that image are applied.  This fixes a bug in which writing
    to an unsigned integer datatype image (with BZERO = 32768) was
    not done correctly.
* Thu Jul 19 2007 lmichnovic@suse.cz
- split off doc subpackage
* Tue Jul 17 2007 lmichnovic@suse.cz
- initial version 3.04
  library package named libcfitsio0
